@@ -1,7 +1,7 @@
 <?php
 /**
  * Copyright 2007 Maintainable Software, LLC
- * Copyright 2008-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2008-2014 Horde LLC (http://www.horde.org/)
  *
  * @author     Mike Naberezny <mike@maintainable.com>
  * @author     Derek DeVries <derek@maintainable.com>
@@ -79,6 +79,13 @@ abstract class Horde_Db_Adapter_Base implements Horde_Db_Adapter
      */
     protected $_cache;
 
+    /**
+     * Cache prefix.
+     *
+     * @var string
+     */
+    protected $_cachePrefix;
+
     /**
      * Log object.
      *
@@ -302,12 +309,24 @@ abstract class Horde_Db_Adapter_Base implements Horde_Db_Adapter
         return true;
     }
 
+    /**
+     * Does this adapter support using INTERVAL statements?  This is +true+
+     * for all adapters except sqlite.
+     *
+     * @return boolean
+     */
+    public function supportsInterval()
+    {
+        return true;
+    }
+
     /**
      * Should primary key values be selected from their corresponding
      * sequence before the insert statement?  If true, next_sequence_value
      * is called before each insert to set the record's primary key.
      * This is false for all adapters but Firebird.
      *
+     * @deprecated
      * @return boolean
      */
     public function prefetchPrimaryKey($tableName = null)
@@ -337,6 +356,39 @@ abstract class Horde_Db_Adapter_Base implements Horde_Db_Adapter
         return $this->_runtime;
     }
 
+    /**
+     * Writes values to the cache handler.
+     *
+     * The key is automatically prefixed to avoid collisions when using
+     * different adapters or different configurations.
+     *
+     * @since Horde_Db 2.1.0
+     *
+     * @param string $key    A cache key.
+     * @param string $value  A value.
+     */
+    public function cacheWrite($key, $value)
+    {
+        $this->_cache->set($this->_cacheKey($key), $value);
+    }
+
+    /**
+     * Reads values from the cache handler.
+     *
+     * The key is automatically prefixed to avoid collisions when using
+     * different adapters or different configurations.
+     *
+     * @since Horde_Db 2.1.0
+     *
+     * @param string $key  A cache key.
+     *
+     * @return string  A value.
+     */
+    public function cacheRead($key)
+    {
+        return $this->_cache->get($this->_cacheKey($key), 0);
+    }
+
 
     /*##########################################################################
     # Connection Management
@@ -387,24 +439,6 @@ abstract class Horde_Db_Adapter_Base implements Horde_Db_Adapter
     # Database Statements
     ##########################################################################*/
 
-    /**
-     * Returns an array of records with the column names as keys, and
-     * column values as values.
-     *
-     * @param string  $sql   SQL statement.
-     * @param mixed $arg1    Either an array of bound parameters or a query
-     *                       name.
-     * @param string $arg2   If $arg1 contains bound parameters, the query
-     *                       name.
-     *
-     * @return PDOStatement
-     * @throws Horde_Db_Exception
-     */
-    public function select($sql, $arg1 = null, $arg2 = null)
-    {
-        return $this->execute($sql, $arg1, $arg2);
-    }
-
     /**
      * Returns an array of record hashes with the column names as keys and
      * column values as values.
@@ -521,71 +555,31 @@ abstract class Horde_Db_Adapter_Base implements Horde_Db_Adapter
     }
 
     /**
-     * Executes the SQL statement in the context of this connection.
+     * Inserts a row including BLOBs into a table.
      *
-     * @param string $sql   SQL statement.
-     * @param mixed $arg1   Either an array of bound parameters or a query
-     *                      name.
-     * @param string $arg2  If $arg1 contains bound parameters, the query
-     *                      name.
+     * @since Horde_Db 2.1.0
      *
-     * @return PDOStatement
-     * @throws Horde_Db_Exception
-     */
-    public function execute($sql, $arg1 = null, $arg2 = null)
-    {
-        if (!$this->isActive()) { $this->reconnect(); }
-
-        if (is_array($arg1)) {
-            $sql = $this->_replaceParameters($sql, $arg1);
-            $name = $arg2;
-        } else {
-            $name = $arg1;
-        }
-
-        $t = new Horde_Support_Timer;
-        $t->push();
-
-        try {
-            $this->_lastQuery = $sql;
-            $stmt = $this->_connection->query($sql);
-        } catch (Exception $e) {
-            $this->_logError($sql, 'QUERY FAILED: ' . $e->getMessage());
-            $this->_logInfo($sql, $name);
-            throw new Horde_Db_Exception($e);
-        }
-
-        $this->_logInfo($sql, $name, $t->pop());
-        $this->_rowCount = $stmt ? $stmt->rowCount() : 0;
-
-        return $stmt;
-    }
-
-    /**
-     * Inserts a row into a table.
-     *
-     * @param string $sql           SQL statement.
-     * @param array|string $arg1    Either an array of bound parameters or a
-     *                              query name.
-     * @param string $arg2          If $arg1 contains bound parameters, the
-     *                              query name.
-     * @param string $pk            The primary key column.
-     * @param integer $idValue      The primary key value. This parameter is
-     *                              required if the primary key is inserted
-     *                              manually.
-     * @param string $sequenceName  The sequence name.
+     * @param string $table     The table name.
+     * @param array $fields     A hash of column names and values. BLOB columns
+     *                          must be provided as Horde_Db_Value_Binary
+     *                          objects.
+     * @param string $pk        The primary key column.
+     * @param integer $idValue  The primary key value. This parameter is
+     *                          required if the primary key is inserted
+     *                          manually.
      *
      * @return integer  Last inserted ID.
      * @throws Horde_Db_Exception
      */
-    public function insert($sql, $arg1 = null, $arg2 = null, $pk = null,
-                           $idValue = null, $sequenceName = null)
+    public function insertBlob($table, $fields, $pk = null, $idValue = null)
     {
-        $this->execute($sql, $arg1, $arg2);
-
-        return $idValue
-            ? $idValue
-            : $this->_connection->lastInsertId($sequenceName);
+        $query = sprintf(
+            'INSERT INTO %s (%s) VALUES (%s)',
+            $table,
+            implode(', ', array_map(array($this, 'quoteColumnName'), array_keys($fields))),
+            implode(', ', array_fill(0, count($fields), '?'))
+        );
+        return $this->insert($query, $fields, $pk, $idValue);
     }
 
     /**
@@ -634,42 +628,6 @@ abstract class Horde_Db_Adapter_Base implements Horde_Db_Adapter
         return (bool)$this->_transactionStarted;
     }
 
-    /**
-     * Begins the transaction (and turns off auto-committing).
-     */
-    public function beginDbTransaction()
-    {
-        if (!$this->_transactionStarted) {
-            $this->_connection->beginTransaction();
-        }
-        $this->_transactionStarted++;
-    }
-
-    /**
-     * Commits the transaction (and turns on auto-committing).
-     */
-    public function commitDbTransaction()
-    {
-        $this->_transactionStarted--;
-        if (!$this->_transactionStarted) {
-            $this->_connection->commit();
-        }
-    }
-
-    /**
-     * Rolls back the transaction (and turns on auto-committing). Must be
-     * done if the transaction block raises an exception or returns false.
-     */
-    public function rollbackDbTransaction()
-    {
-        if (!$this->_transactionStarted) {
-            return;
-        }
-
-        $this->_connection->rollBack();
-        $this->_transactionStarted = 0;
-    }
-
     /**
      * Appends LIMIT and OFFSET options to a SQL statement.
      *
@@ -828,4 +786,21 @@ abstract class Horde_Db_Adapter_Base implements Horde_Db_Adapter
     {
         return "SQL $message  \n\t" . wordwrap(preg_replace("/\s+/", ' ', $sql), 70, "\n\t  ", 1);
     }
+
+    /**
+     * Returns the prefixed cache key to use.
+     *
+     * @param string $key  A cache key.
+     *
+     * @return string  Prefixed cache key.
+     */
+    protected function _cacheKey($key)
+    {
+        if (!isset($this->_cachePrefix)) {
+            $this->_cachePrefix = get_class($this) . hash((PHP_MINOR_VERSION >= 4) ? 'fnv132' : 'sha1', serialize($this->_config));
+        }
+
+        return $this->_cachePrefix . $key;
+    }
+
 }
