@@ -1,10 +1,7 @@
 <?php
 /**
- * Class for MySQL-specific managing of database schemes and handling of SQL
- * dialects and quoting.
- *
  * Copyright 2007 Maintainable Software, LLC
- * Copyright 2008-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2008-2014 Horde LLC (http://www.horde.org/)
  *
  * @author     Mike Naberezny <mike@maintainable.com>
  * @author     Derek DeVries <derek@maintainable.com>
@@ -17,6 +14,9 @@
  */
 
 /**
+ * Class for MySQL-specific managing of database schemes and handling of SQL
+ * dialects and quoting.
+ *
  * @author     Mike Naberezny <mike@maintainable.com>
  * @author     Derek DeVries <derek@maintainable.com>
  * @author     Chuck Hagenbuch <chuck@horde.org>
@@ -83,26 +83,6 @@ class Horde_Db_Adapter_Mysql_Schema extends Horde_Db_Adapter_Base_Schema
         return str_replace('.', '`.`', $this->quoteColumnName($name));
     }
 
-    /**
-     * Returns a quoted boolean true.
-     *
-     * @return string  The quoted boolean true.
-     */
-    public function quoteTrue()
-    {
-        return '1';
-    }
-
-    /**
-     * Returns a quoted boolean false.
-     *
-     * @return string  The quoted boolean false.
-     */
-    public function quoteFalse()
-    {
-        return '0';
-    }
-
 
     /*##########################################################################
     # Schema Statements
@@ -160,14 +140,14 @@ class Horde_Db_Adapter_Mysql_Schema extends Horde_Db_Adapter_Base_Schema
     public function primaryKey($tableName, $name = null)
     {
         // Share the column cache with the columns() method
-        $rows = @unserialize($this->_cache->get("tables/columns/$tableName", 0));
+        $rows = @unserialize($this->cacheRead("tables/columns/$tableName"));
 
         if (!$rows) {
             $rows = $this->selectAll(
                 'SHOW FIELDS FROM ' . $this->quoteTableName($tableName),
                 $name);
 
-            $this->_cache->set("tables/columns/$tableName", serialize($rows));
+            $this->cacheWrite("tables/columns/$tableName", serialize($rows));
         }
 
         $pk = $this->makeIndex($tableName, 'PRIMARY', true, true, array());
@@ -190,7 +170,7 @@ class Horde_Db_Adapter_Mysql_Schema extends Horde_Db_Adapter_Base_Schema
      */
     public function indexes($tableName, $name=null)
     {
-        $indexes = @unserialize($this->_cache->get("tables/indexes/$tableName", 0));
+        $indexes = @unserialize($this->cacheRead("tables/indexes/$tableName"));
 
         if (!$indexes) {
             $indexes = array();
@@ -207,7 +187,7 @@ class Horde_Db_Adapter_Mysql_Schema extends Horde_Db_Adapter_Base_Schema
                 $indexes[count($indexes) - 1]->columns[] = $row['Column_name'];
             }
 
-            $this->_cache->set("tables/indexes/$tableName", serialize($indexes));
+            $this->cacheWrite("tables/indexes/$tableName", serialize($indexes));
         }
 
         return $indexes;
@@ -223,12 +203,12 @@ class Horde_Db_Adapter_Mysql_Schema extends Horde_Db_Adapter_Base_Schema
      */
     public function columns($tableName, $name=null)
     {
-        $rows = @unserialize($this->_cache->get("tables/columns/$tableName", 0));
+        $rows = @unserialize($this->cacheRead("tables/columns/$tableName"));
 
         if (!$rows) {
             $rows = $this->selectAll('SHOW FIELDS FROM ' . $this->quoteTableName($tableName), $name);
 
-            $this->_cache->set("tables/columns/$tableName", serialize($rows));
+            $this->cacheWrite("tables/columns/$tableName", serialize($rows));
         }
 
         // Create columns from rows.
@@ -426,13 +406,9 @@ class Horde_Db_Adapter_Mysql_Schema extends Horde_Db_Adapter_Base_Schema
      *                               - name: (string) the index name to fall
      *                                 back to if no column names specified.
      */
-    public function indexName($tableName, $options=array())
+    public function indexName($tableName, $options = array())
     {
-        $indexName = parent::indexName($tableName, $options);
-        if (strlen($indexName) > 64) {
-            $indexName = substr($indexName, 0, 64);
-        }
-        return $indexName;
+        return substr(parent::indexName($tableName, $options), 0, 64);
     }
 
     /**
