@@ -1,10 +1,7 @@
 <?php
 /**
- * Class for PostgreSQL-specific managing of database schemes and handling of
- * SQL dialects and quoting.
- *
  * Copyright 2007 Maintainable Software, LLC
- * Copyright 2008-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2008-2014 Horde LLC (http://www.horde.org/)
  *
  * @author     Mike Naberezny <mike@maintainable.com>
  * @author     Derek DeVries <derek@maintainable.com>
@@ -17,6 +14,9 @@
  */
 
 /**
+ * Class for PostgreSQL-specific managing of database schemes and handling of
+ * SQL dialects and quoting.
+ *
  * @author     Mike Naberezny <mike@maintainable.com>
  * @author     Derek DeVries <derek@maintainable.com>
  * @author     Chuck Hagenbuch <chuck@horde.org>
@@ -105,31 +105,19 @@ class Horde_Db_Adapter_Postgresql_Schema extends Horde_Db_Adapter_Base_Schema
             return "'" . $value . "'";
         }
         if (is_string($value) && substr($column->getSqlType(), 0, 3) == 'bit') {
-            if (preg_match('/^[01]*$/', $value)) {
-                // Bit-string notation
-                return "B'" . $value . "'";
-            }
             if (preg_match('/^[0-9A-F]*$/i')) {
                 // Hexadecimal notation
                 return "X'" . $value . "'";
             }
+            if (preg_match('/^[01]*$/', $value)) {
+                // Bit-string notation
+                return "B'" . $value . "'";
+            }
         }
 
         return parent::quote($value, $column);
     }
 
-    /**
-     * Returns a quoted form of the column name.
-     *
-     * @param string $name  A column name.
-     *
-     * @return string  The quoted column name.
-     */
-    public function quoteColumnName($name)
-    {
-        return '"' . str_replace('"', '""', $name) . '"';
-    }
-
     /**
      * Returns a quoted sequence name.
      *
@@ -144,6 +132,26 @@ class Horde_Db_Adapter_Postgresql_Schema extends Horde_Db_Adapter_Base_Schema
         return '\'' . str_replace('"', '""', $name) . '\'';
     }
 
+    /**
+     * Returns a quoted boolean true.
+     *
+     * @return string  The quoted boolean true.
+     */
+    public function quoteTrue()
+    {
+        return "'t'";
+    }
+
+    /**
+     * Returns a quoted boolean false.
+     *
+     * @return string  The quoted boolean false.
+     */
+    public function quoteFalse()
+    {
+        return "'f'";
+    }
+
     /**
      * Returns a quoted binary value.
      *
@@ -175,6 +183,7 @@ class Horde_Db_Adapter_Postgresql_Schema extends Horde_Db_Adapter_Base_Schema
         return sprintf('\\\\%03.o', ord($matches[0]));
     }
 
+
     /*##########################################################################
     # Schema Statements
     ##########################################################################*/
@@ -289,7 +298,7 @@ class Horde_Db_Adapter_Postgresql_Schema extends Horde_Db_Adapter_Base_Schema
      */
     public function indexes($tableName, $name = null)
     {
-        $indexes = @unserialize($this->_cache->get("tables/indexes/$tableName", 0));
+        $indexes = @unserialize($this->cacheRead("tables/indexes/$tableName"));
 
         if (!$indexes) {
             $schemas = array();
@@ -328,7 +337,7 @@ class Horde_Db_Adapter_Postgresql_Schema extends Horde_Db_Adapter_Base_Schema
                 $indexes[count($indexes) - 1]->columns[] = $row['attname'];
             }
 
-            $this->_cache->set("tables/indexes/$tableName", serialize($indexes));
+            $this->cacheWrite("tables/indexes/$tableName", serialize($indexes));
         }
 
         return $indexes;
@@ -344,12 +353,12 @@ class Horde_Db_Adapter_Postgresql_Schema extends Horde_Db_Adapter_Base_Schema
      */
     public function columns($tableName, $name = null)
     {
-        $rows = @unserialize($this->_cache->get("tables/columns/$tableName", 0));
+        $rows = @unserialize($this->cacheRead("tables/columns/$tableName"));
 
         if (!$rows) {
             $rows = $this->_columnDefinitions($tableName, $name);
 
-            $this->_cache->set("tables/columns/$tableName", serialize($rows));
+            $this->cacheWrite("tables/columns/$tableName", serialize($rows));
         }
 
         // Create columns from rows.
@@ -520,16 +529,7 @@ class Horde_Db_Adapter_Postgresql_Schema extends Horde_Db_Adapter_Base_Schema
             try {
                 // Booleans can't always be cast to other data types; do extra
                 // work to handle them.
-                $oldType = null;
-                foreach ($this->columns($tableName) as $column) {
-                    if ($column->getName() == $columnName) {
-                        $oldType = $column->getType();
-                        break;
-                    }
-                }
-                if ($oldType === null) {
-                    throw new Horde_Db_Exception("$tableName does not have a column '$columnName'");
-                }
+                $oldType = $this->column($tableName, $columnName)->getType();
 
                 $this->beginDbTransaction();
 
@@ -940,7 +940,7 @@ class Horde_Db_Adapter_Postgresql_Schema extends Horde_Db_Adapter_Base_Schema
         case '&':
             /* Only PgSQL 7.3+ understands SQL99 'SIMILAR TO'; use ~ for
              * greater backwards compatibility. */
-            $query = 'CASE WHEN CAST(%s AS VARCHAR) ~ \'^-?[0-9]+$\' THEN (CAST(%s AS INTEGER) %s %s) <> 0 ELSE FALSE END';
+            $query = 'CASE WHEN CAST(%s AS VARCHAR) ~ \'^-?[0-9]+$\' THEN (CAST(%s AS INTEGER) %s %s) ELSE 0 END';
             if ($bind) {
                 return array(sprintf($query, $lhs, $lhs, $op, '?'),
                              array((int)$rhs));
