@@ -1,10 +1,7 @@
 <?php
 /**
- * Class for SQLite-specific managing of database schemes and handling of SQL
- * dialects and quoting.
- *
  * Copyright 2007 Maintainable Software, LLC
- * Copyright 2008-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2008-2014 Horde LLC (http://www.horde.org/)
  *
  * @author     Mike Naberezny <mike@maintainable.com>
  * @author     Derek DeVries <derek@maintainable.com>
@@ -17,6 +14,9 @@
  */
 
 /**
+ * Class for SQLite-specific managing of database schemes and handling of SQL
+ * dialects and quoting.
+ *
  * @author     Mike Naberezny <mike@maintainable.com>
  * @author     Derek DeVries <derek@maintainable.com>
  * @author     Chuck Hagenbuch <chuck@horde.org>
@@ -57,38 +57,6 @@ class Horde_Db_Adapter_Sqlite_Schema extends Horde_Db_Adapter_Base_Schema
     # Quoting
     ##########################################################################*/
 
-    /**
-     * Returns a quoted form of the column name.
-     *
-     * @param string $name  A column name.
-     *
-     * @return string  The quoted column name.
-     */
-    public function quoteColumnName($name)
-    {
-        return '"' . str_replace('"', '""', $name) . '"';
-    }
-
-    /**
-     * Returns a quoted boolean true.
-     *
-     * @return string  The quoted boolean true.
-     */
-    public function quoteTrue()
-    {
-        return '1';
-    }
-
-    /**
-     * Returns a quoted boolean false.
-     *
-     * @return string  The quoted boolean false.
-     */
-    public function quoteFalse()
-    {
-        return '0';
-    }
-
     /**
      * Returns a quoted binary value.
      *
@@ -158,17 +126,17 @@ class Horde_Db_Adapter_Sqlite_Schema extends Horde_Db_Adapter_Base_Schema
     public function primaryKey($tableName, $name = null)
     {
         // Share the columns cache with the columns() method
-        $rows = @unserialize($this->_cache->get("tables/columns/$tableName", 0));
+        $rows = @unserialize($this->cacheRead("tables/columns/$tableName"));
 
         if (!$rows) {
             $rows = $this->selectAll('PRAGMA table_info(' . $this->quoteTableName($tableName) . ')', $name);
 
-            $this->_cache->set("tables/columns/$tableName", serialize($rows));
+            $this->cacheWrite("tables/columns/$tableName", serialize($rows));
         }
 
         $pk = $this->makeIndex($tableName, 'PRIMARY', true, true, array());
         foreach ($rows as $row) {
-            if ($row['pk'] == 1) {
+            if ($row['pk']) {
                 $pk->columns[] = $row['name'];
             }
         }
@@ -186,7 +154,7 @@ class Horde_Db_Adapter_Sqlite_Schema extends Horde_Db_Adapter_Base_Schema
      */
     public function indexes($tableName, $name = null)
     {
-        $indexes = @unserialize($this->_cache->get("tables/indexes/$tableName", 0));
+        $indexes = @unserialize($this->cacheRead("tables/indexes/$tableName"));
 
         if (!$indexes) {
             $indexes = array();
@@ -204,7 +172,7 @@ class Horde_Db_Adapter_Sqlite_Schema extends Horde_Db_Adapter_Base_Schema
                 $indexes[] = $index;
             }
 
-            $this->_cache->set("tables/indexes/$tableName", serialize($indexes));
+            $this->cacheWrite("tables/indexes/$tableName", serialize($indexes));
         }
 
         return $indexes;
@@ -220,11 +188,11 @@ class Horde_Db_Adapter_Sqlite_Schema extends Horde_Db_Adapter_Base_Schema
      */
     public function columns($tableName, $name = null)
     {
-        $rows = @unserialize($this->_cache->get("tables/columns/$tableName", 0));
+        $rows = @unserialize($this->cacheRead("tables/columns/$tableName"));
 
         if (!$rows) {
             $rows = $this->selectAll('PRAGMA table_info(' . $this->quoteTableName($tableName) . ')', $name);
-            $this->_cache->set("tables/columns/$tableName", serialize($rows));
+            $this->cacheWrite("tables/columns/$tableName", serialize($rows));
         }
 
         // create columns from rows
@@ -307,12 +275,15 @@ class Horde_Db_Adapter_Sqlite_Schema extends Horde_Db_Adapter_Base_Schema
     {
         $this->_clearTableCache($tableName);
 
-        $defs = array(sprintf('$definition["%s"]->setType("%s"); if ("%s" == "autoincrementKey") $definition->primaryKey(false);', $columnName, $type, $type));
+        $defs = array(
+            sprintf('$definition["%s"]->setType("%s");', $columnName, $type),
+            sprintf('if ("%s" == "autoincrementKey") $definition->primaryKey(false);', $type)
+        );
         if (isset($options['limit'])) {
             $defs[] = sprintf('$definition["%s"]->setLimit("%s");', $columnName, $options['limit']);
         }
         if (isset($options['null'])) {
-            $defs[] = sprintf('$definition["%s"]->setNull("%s");', $columnName, $options['null']);
+            $defs[] = sprintf('$definition["%s"]->setNull((bool)%d);', $columnName, $options['null']);
         }
         if (isset($options['precision'])) {
             $defs[] = sprintf('$definition["%s"]->setPrecision("%s");', $columnName, $options['precision']);
@@ -635,14 +606,16 @@ class Horde_Db_Adapter_Sqlite_Schema extends Horde_Db_Adapter_Base_Schema
             $columnType = $column->getName() == $pkColumn
                 ? 'autoincrementKey'
                 : $column->getType();
+            $columnOptions = array('limit' => $column->getLimit());
 
             if ($columnType == 'autoincrementKey') {
                 $copyPk = false;
+            } else {
+                $columnOptions['default'] = $column->getDefault();
+                $columnOptions['null'] = $column->isNull();
             }
-            $definition->column($columnName, $columnType,
-                                array('limit' => $column->getLimit(),
-                                      'default' => $column->getDefault(),
-                                      'null' => $column->isNull()));
+
+            $definition->column($columnName, $columnType, $columnOptions);
         }
 
         if ($pkColumn && count($pk->columns) && $copyPk) {
